# 0.5.0 - 2023-11-13

### Added
- `precision` command

### Fixed
- Fixed #17 - Custom numeric precision not taken into account

# 0.4.0 - 2023-11-10

### Added
- Average divergence
- Allow cancelling screenshots
- `move_dist` command
- Value control commands without args now print out the current value
- `zoom_lvl` command
- `pos` command
- Show zoom level in canvas border subtitle
- `click_pos` command

# Fixed
- Some errors in help messages, and better formating

# 0.3.1 - 2023-11-06

### Fixed
- Fix random error at startup

# 0.3.0 - 2023-10-30

### Added
- Capture command
- CaptureFit command 
- MaxIter command
- Extra help for commands (`help command_name`)

### Fixed
- Errors in help messages

# 0.2.0 - 2023-10-30

### Added
- Command input below log panel
- `-v` / `--version` option
- Published on PyPI

### Fixed
- Minor imperfections

### Changed
- Bump click_extra to 4.7.1

# O.1.0-beta - 2023-10-26

### Added 

- Base code